from sqlalchemy import Column, Integer, ForeignKey
from Kuyil.entity.base import Base


class DatasetRepositoryEntity(Base):
    __tablename__ = 'datatset_repository'

    id = Column(Integer, primary_key=True)
    repository_id = Column(Integer, ForeignKey("repository_client_factory.id"), primary_key=True)
    dataset_id = Column(Integer, ForeignKey("dataset.id"), primary_key=True)

    def __repr__(self):
        return "<DatasetRepository(repository_id='%s', dataset_id='%s')>" % \
               (self.repository_id, self.dataset_id)



class Dataset():

    def __init__(self, dataset_class, instance, label, repository, comment=None,
                 metadata=None):
        self.instance = instance
        self.dataset_class = dataset_class
        self.label = label
        self.repository = repository
        self.comment = comment
        self.metadata = metadata


    def get_write_lock_if_idle(self):
        print()

    def maintain_write_lock(self, pid):
        print()

    def write_failed(self, pid, comment=None):
        print()

    def write_success(self, pid, comment=None):
        print()


from Kuyil.entity.repository_entity import RepositoryEntity


class Kuyil:

    @staticmethod
    def get_repository(name):
        print("Hi")

    @staticmethod
    def create_dataset(dataset_class, instance, label, repository, comment=None,
                       metadata=None,only_create=False):
        print()




class Repository():

    def init(self):
        print()

    def maintain_write_lock(self, pid):
        print()

    def write_failed(self, pid, comment=None):
        print()

    def write_success(self, pid, comment=None):
        print()


from sqlalchemy import Column, Integer, String, NVARCHAR, UniqueConstraint
from Kuyil.entity.base import Base


class RepositoryEntity(Base):

    __tablename__ = 'repository_client_factory'

    __mapper_args__ = {
        'exclude_properties': ['client']
    }

    id = Column(Integer, primary_key=True)
    config = Column(NVARCHAR)
    name = Column(String(500))
    client = None
    UniqueConstraint('name')

    def init(self):
        # call repository_client_factory client factory and get client
        self.client = ""

    def __repr__(self):
        return "<Repository(name='%s', config='%s')>" % (self.name, self.config)



from setuptools import setup

setup(name = 'Kuyil',
        version='0.1a',
        license='BSD',
        url='https://github.com/4info/Kuyil',
        description='testing sample rsj',
        author='rohitash',
        author_email='rohitash@sigmoid.com',
        packages=['Kuyil',
                'Kuyil.api',
                'Kuyil.dao',
                'Kuyil.db_connection',
                'Kuyil.entity',
                'Kuyil.util',
                'Kuyil.repository_client_factory'],

        install_requires=['SQLAlchemy==1.2.2'],
)

__author__ = 'rohitash'


from sqlalchemy import Column, Integer, String, BigInteger, Boolean, NVARCHAR, \
    DateTime, UniqueConstraint, VARCHAR
from Kuyil.entity.base import Base
from sqlalchemy.orm import relationship


class DatasetEntity(Base):

    __tablename__ = 'dataset'

    id = Column(Integer, primary_key=True)
    dataset_class = Column(String(500))
    instance = Column(String(500))
    label = Column(String(100))
    version = Column(BigInteger)
    tags = Column(String(500), nullable=True)
    alt_uri = Column(VARCHAR, nullable=True)
    read_lock_ts = Column(DateTime, nullable=True)
    write_lock_id = Column(BigInteger, nullable=True)
    write_lock_ts = Column(DateTime, nullable=True)
    is_expired = Column(Boolean, nullable=True)
    is_valid = Column(Boolean)
    is_incomplete = Column(Boolean)
    is_marked_for_deletion = Column(Boolean, nullable=True)
    is_deleted = Column(Boolean, nullable=True)
    created_ts = Column(DateTime)
    modified_ts = Column(DateTime, nullable=True)
    dataset_created_ts = Column(DateTime)
    dataset_ready_ts = Column(DateTime, nullable=True)
    dataset_modified_ts = Column(DateTime, nullable=True)
    dataset_marked_for_deletion_ts = Column(DateTime, nullable=True)
    dataset_deleted_ts = Column(DateTime, nullable=True)
    dataset_expired_ts = Column(DateTime, nullable=True)
    dataset_restored_ts = Column(DateTime, nullable=True)
    comment = Column(NVARCHAR, nullable=True)
    metadata = Column(NVARCHAR, nullable=True)
    bytes = Column(BigInteger, nullable=True)
    lines = Column(Integer, nullable=True)

    repositories = relationship(
        'repository_client_factory',
        secondary='datatset_repository'
    )

    UniqueConstraint('dataset_class', 'instance', 'label', '__version')

    def __repr__(self):
        return "<Dataset(class='%s', instance='%s', label='%s', id='%s')>" % \
               (self.dataset_class, self.instance, self.label, self.id)